summaryrefslogtreecommitdiff
path: root/compiler/GHC/Cmm.hs
diff options
context:
space:
mode:
Diffstat (limited to 'compiler/GHC/Cmm.hs')
-rw-r--r--compiler/GHC/Cmm.hs8
1 files changed, 5 insertions, 3 deletions
diff --git a/compiler/GHC/Cmm.hs b/compiler/GHC/Cmm.hs
index d52c3ad801..9973db8d0d 100644
--- a/compiler/GHC/Cmm.hs
+++ b/compiler/GHC/Cmm.hs
@@ -197,11 +197,13 @@ data Section = Section SectionType CLabel
data CmmStatic
= CmmStaticLit CmmLit
- -- a literal value, size given by cmmLitRep of the literal.
+ -- ^ a literal value, size given by cmmLitRep of the literal.
| CmmUninitialised Int
- -- uninitialised data, N bytes long
+ -- ^ uninitialised data, N bytes long
| CmmString ByteString
- -- string of 8-bit values only, not zero terminated.
+ -- ^ string of 8-bit values only, not zero terminated.
+ | CmmFileEmbed FilePath
+ -- ^ an embedded binary file
-- Static data before SRT generation
data CmmStatics